aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/functions_install.php
diff options
context:
space:
mode:
authorMarc Alexander <admin@m-a-styles.de>2014-04-11 11:05:59 +0200
committerMarc Alexander <admin@m-a-styles.de>2014-04-11 11:11:31 +0200
commit03667081e1d0a33e7867e9e261044369c45dd8ad (patch)
treecccfdbfade471675bb31f90a58c3340f65a158ac /phpBB/includes/functions_install.php
parent22090dc3a3280d043ff5e77212ee7229b5eb0d24 (diff)
downloadforums-03667081e1d0a33e7867e9e261044369c45dd8ad.tar
forums-03667081e1d0a33e7867e9e261044369c45dd8ad.tar.gz
forums-03667081e1d0a33e7867e9e261044369c45dd8ad.tar.bz2
forums-03667081e1d0a33e7867e9e261044369c45dd8ad.tar.xz
forums-03667081e1d0a33e7867e9e261044369c45dd8ad.zip
[ticket/12386] Rename DEBUG_EXTRA to DEBUG_CONTAINER for more descriptive name
PHPBB3-12386
Diffstat (limited to 'phpBB/includes/functions_install.php')
-rw-r--r--phpBB/includes/functions_install.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/phpBB/includes/functions_install.php b/phpBB/includes/functions_install.php
index 406cc4fb03..4f8ec99d88 100644
--- a/phpBB/includes/functions_install.php
+++ b/phpBB/includes/functions_install.php
@@ -486,14 +486,14 @@ function adjust_language_keys_callback($matches)
* @param array $data Array containing the database connection information
* @param string $dbms The name of the DBAL class to use
* @param bool $debug If the debug constants should be enabled by default or not
* @param bool $debug_extra If the container should be compiled on
* every page load or not
* @param bool $debug_test If the DEBUG_TEST constant should be added
* NOTE: Only for use within the testing framework
*
* @return string The output to write to the file
*/
-function phpbb_create_config_file_data($data, $dbms, $debug = false, $debug_extra = false, $debug_test = false)
+function phpbb_create_config_file_data($data, $dbms, $debug = false, $debug_container = false, $debug_test = false)
{
$config_data = "<?php\n";
$config_data .= "// phpBB 3.1.x auto-generated configuration file\n// Do not change anything in this file!\n";
@@ -528,13 +528,13 @@ function phpbb_create_config_file_data($data, $dbms, $debug = false, $debug_extr
$config_data .= "// @define('DEBUG', true);\n";
}
- if ($debug_extra)
+ if ($debug_container)
{
- $config_data .= "@define('DEBUG_EXTRA', true);\n";
+ $config_data .= "@define('DEBUG_CONTAINER', true);\n";
}
else
{
- $config_data .= "// @define('DEBUG_EXTRA', true);\n";
+ $config_data .= "// @define('DEBUG_CONTAINER', true);\n";
}
if ($debug_test)
@@ -486,14 +486,14 @@ function adjust_language_keys_callback($matches)
* @param string $dbms The name of the DBAL class to use
* @param bool $debug If the debug constants should be enabled by default or not
-* @param bool $debug_extra If the container should be compiled on
+* @param bool $debug_container If the container should be compiled on
* every page load or not
* @param bool $debug_test If the DEBUG_TEST constant should be added